pub enum ActionAnchor {
AfterSlot {
slots: Vec<u64>,
},
BeforeMatch {
filter: DiscoveryFilter,
},
AfterMatch {
filter: DiscoveryFilter,
},
}Expand description
Where a ScheduledAction fires.
Variants
AfterSlot
At the end of each slot, after its transactions execute but before it finalizes. Fires the entry for the current slot, if any.
BeforeMatch
Before each batch matching filter executes. The whole sequence fires at
each matching batch.
Fields

filter: DiscoveryFilterAfterMatch
After each batch matching filter commits. The whole sequence fires at
each matching batch.
Fields

filter: DiscoveryFilterTrait Implementations
Sourceimpl Clone for ActionAnchor
impl Clone for ActionAnchor
Sourcefn clone(&self) -> ActionAnchor
fn clone(&self) -> ActionAnchor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionAnchor
impl Debug for ActionAnchor
Sourceimpl<'de> Deserialize<'de> for ActionAnchor
impl<'de> Deserialize<'de> for ActionAnchor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ActionAnchor
Sourceimpl PartialEq for ActionAnchor
impl PartialEq for ActionAnchor
Sourceimpl Serialize for ActionAnchor
impl Serialize for ActionAnchor
impl StructuralPartialEq for ActionAnchor