pub enum ActionAnchor {
AfterSlot,
BeforeMatch {
filter: DiscoveryFilter,
},
AfterMatch {
filter: DiscoveryFilter,
},
}Expand description
Where a ScheduledAction fires.
Variants
AfterSlot
At the end of each slot, after its transactions execute but before it finalizes.
BeforeMatch
Before each batch matching filter executes.
Fields

filter: DiscoveryFilterAfterMatch
After each batch matching filter commits.
Fields

filter: DiscoveryFilterTrait Implementations
Sourceimpl Clone for ActionAnchor
impl Clone for ActionAnchor
Sourcefn clone(&self) -> ActionAnchor
fn clone(&self) -> ActionAnchor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionAnchor
impl Debug for ActionAnchor
Sourceimpl Default for ActionAnchor
impl Default for ActionAnchor
Sourcefn default() -> ActionAnchor
fn default() -> ActionAnchor
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ActionAnchor
impl<'de> Deserialize<'de> for ActionAnchor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ActionAnchor
Sourceimpl PartialEq for ActionAnchor
impl PartialEq for ActionAnchor
Sourcefn eq(&self, other: &ActionAnchor) -> bool
fn eq(&self, other: &ActionAnchor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ActionAnchor
impl Serialize for ActionAnchor
impl StructuralPartialEq for ActionAnchor