pub struct SessionSummary {
pub correct_simulation: usize,
pub incorrect_simulation: usize,
pub execution_errors: usize,
pub balance_diff: usize,
pub log_diff: usize,
}Expand description
Summary of transaction execution statistics for a completed backtest session.
Fields
correct_simulation: usizeNumber of simulations where simulator outcome matched on-chain outcome
(true_success + true_failure).
incorrect_simulation: usizeNumber of simulations where simulator outcome did not match on-chain outcome
(false_success + false_failure).
execution_errors: usizeNumber of transactions that had execution errors in simulation.
balance_diff: usizeNumber of transactions with different balance diffs.
log_diff: usizeNumber of transactions with different log diffs.
Implementations
Sourceimpl SessionSummary
impl SessionSummary
Sourcepub fn has_deviations(&self) -> bool
pub fn has_deviations(&self) -> bool
Returns true if there were any execution deviations (errors or mismatched results).
Sourcepub fn total_transactions(&self) -> usize
pub fn total_transactions(&self) -> usize
Total number of transactions processed.